summaryrefslogtreecommitdiff
path: root/scripts/build
diff options
context:
space:
mode:
authorAlexey Neyman <stilor@att.net>2019-04-05 21:09:48 (GMT)
committerGitHub <noreply@github.com>2019-04-05 21:09:48 (GMT)
commit51f1db5c0aed562caf6d195ee5d3666ee33cc0ad (patch)
treedfcb47a7f71ddb84e81e6a89530dcaf4f33b0dfe /scripts/build
parentace18924a37dce89d9476dfc9a4ec329e77660a2 (diff)
parent693d3943b10665b99a31ab1f3b4058fb4b3a32d1 (diff)
Merge pull request #1178 from stilor/master
Last fixes for 1.24.0
Diffstat (limited to 'scripts/build')
-rw-r--r--scripts/build/binutils/binutils.sh10
-rw-r--r--scripts/build/cc/gcc.sh30
-rw-r--r--scripts/build/companion_libs/050-zlib.sh2
-rw-r--r--scripts/build/companion_libs/100-gmp.sh4
-rw-r--r--scripts/build/companion_libs/110-mpfr.sh4
-rw-r--r--scripts/build/companion_libs/121-isl.sh4
-rw-r--r--scripts/build/companion_libs/130-cloog.sh4
-rw-r--r--scripts/build/companion_libs/140-mpc.sh4
-rw-r--r--scripts/build/companion_libs/210-expat.sh2
-rw-r--r--scripts/build/companion_libs/220-ncurses.sh2
-rw-r--r--scripts/build/companion_libs/320-libiconv.sh2
-rw-r--r--scripts/build/companion_libs/330-gettext.sh2
-rw-r--r--scripts/build/debug/300-gdb.sh14
-rw-r--r--scripts/build/libc/avr-libc.sh2
-rw-r--r--scripts/build/libc/glibc.sh14
-rw-r--r--scripts/build/libc/mingw-w64.sh2
-rw-r--r--scripts/build/libc/musl.sh2
-rw-r--r--scripts/build/libc/newlib.sh2
-rw-r--r--scripts/build/libc/uClibc.sh2
19 files changed, 54 insertions, 54 deletions
diff --git a/scripts/build/binutils/binutils.sh b/scripts/build/binutils/binutils.sh
index 4d1bf46..2a738de 100644
--- a/scripts/build/binutils/binutils.sh
+++ b/scripts/build/binutils/binutils.sh
@@ -199,11 +199,11 @@ do_binutils_backend() {
if [ "${static_build}" = "y" ]; then
extra_make_flags+=("LDFLAGS=${ldflags} -all-static")
CT_DoLog EXTRA "Prepare binutils for static build"
- CT_DoExecLog ALL make ${JOBSFLAGS} configure-host
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} configure-host
fi
CT_DoLog EXTRA "Building binutils"
- CT_DoExecLog ALL make "${extra_make_flags[@]}" ${JOBSFLAGS}
+ CT_DoExecLog ALL make "${extra_make_flags[@]}" ${CT_JOBSFLAGS}
CT_DoLog EXTRA "Installing binutils"
CT_DoExecLog ALL make install
@@ -222,7 +222,7 @@ do_binutils_backend() {
fi
manuals_install=( "${manuals_for[@]/#/install-pdf-}" )
manuals_install+=( "${manuals_for[@]/#/install-html-}" )
- CT_DoExecLog ALL make ${JOBSFLAGS} pdf html
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} pdf html
CT_DoExecLog ALL make "${manuals_install[@]}"
fi
@@ -290,7 +290,7 @@ do_elf2flt_backend() {
"${CT_ELF2FLT_EXTRA_CONFIG_ARRAY[@]}"
CT_DoLog EXTRA "Building elf2flt"
- CT_DoExecLog ALL make ${JOBSFLAGS} CPU=${CT_ARCH}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} CPU=${CT_ARCH}
CT_DoLog EXTRA "Installing elf2flt"
CT_DoExecLog ALL make install
@@ -349,7 +349,7 @@ do_binutils_for_target() {
"${CT_BINUTILS_EXTRA_CONFIG_ARRAY[@]}"
CT_DoLog EXTRA "Building binutils' libraries (${targets[*]}) for target"
- CT_DoExecLog ALL make ${JOBSFLAGS} "${build_targets[@]}"
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} "${build_targets[@]}"
CT_DoLog EXTRA "Installing binutils' libraries (${targets[*]}) for target"
CT_DoExecLog ALL make DESTDIR="${CT_SYSROOT_DIR}" "${install_targets[@]}"
diff --git a/scripts/build/companion_libs/050-zlib.sh b/scripts/build/companion_libs/050-zlib.sh
index 868bf3d..8c6a0f6 100644
--- a/scripts/build/companion_libs/050-zlib.sh
+++ b/scripts/build/companion_libs/050-zlib.sh
@@ -113,7 +113,7 @@ do_zlib_backend() {
esac
CT_DoLog EXTRA "Building zlib"
- CT_DoExecLog ALL make "${extra_make[@]}" ${JOBSFLAGS}
+ CT_DoExecLog ALL make "${extra_make[@]}" ${CT_JOBSFLAGS}
if [ "${CT_COMPLIBS_CHECK}" = "y" ]; then
if [ "${host}" = "${CT_BUILD}" ]; then
diff --git a/scripts/build/companion_libs/100-gmp.sh b/scripts/build/companion_libs/100-gmp.sh
index 272af66..4e8c12f 100644
--- a/scripts/build/companion_libs/100-gmp.sh
+++ b/scripts/build/companion_libs/100-gmp.sh
@@ -105,12 +105,12 @@ do_gmp_backend() {
"${extra_config[@]}"
CT_DoLog EXTRA "Building GMP"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
if [ "${CT_COMPLIBS_CHECK}" = "y" ]; then
if [ "${host}" = "${CT_BUILD}" ]; then
CT_DoLog EXTRA "Checking GMP"
- CT_DoExecLog ALL make ${JOBSFLAGS} -s check
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} -s check
else
# Cannot run host binaries on build in a canadian cross
CT_DoLog EXTRA "Skipping check for GMP on the host"
diff --git a/scripts/build/companion_libs/110-mpfr.sh b/scripts/build/companion_libs/110-mpfr.sh
index b4be3f4..d2cb9f6 100644
--- a/scripts/build/companion_libs/110-mpfr.sh
+++ b/scripts/build/companion_libs/110-mpfr.sh
@@ -122,12 +122,12 @@ do_mpfr_backend() {
--enable-static
CT_DoLog EXTRA "Building MPFR"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
if [ "${CT_COMPLIBS_CHECK}" = "y" ]; then
if [ "${host}" = "${CT_BUILD}" ]; then
CT_DoLog EXTRA "Checking MPFR"
- CT_DoExecLog ALL make ${JOBSFLAGS} -s check
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} -s check
else
# Cannot run host binaries on build in a canadian cross
CT_DoLog EXTRA "Skipping check for MPFR on the host"
diff --git a/scripts/build/companion_libs/121-isl.sh b/scripts/build/companion_libs/121-isl.sh
index d96e9ce..8b1b720 100644
--- a/scripts/build/companion_libs/121-isl.sh
+++ b/scripts/build/companion_libs/121-isl.sh
@@ -110,12 +110,12 @@ do_isl_backend() {
--with-clang=no
CT_DoLog EXTRA "Building ISL"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
if [ "${CT_COMPLIBS_CHECK}" = "y" ]; then
if [ "${host}" = "${CT_BUILD}" ]; then
CT_DoLog EXTRA "Checking ISL"
- CT_DoExecLog ALL make ${JOBSFLAGS} -s check
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} -s check
else
# Cannot run host binaries on build in a canadian cross
CT_DoLog EXTRA "Skipping check for ISL on the host"
diff --git a/scripts/build/companion_libs/130-cloog.sh b/scripts/build/companion_libs/130-cloog.sh
index e0f89eb..9ee897a 100644
--- a/scripts/build/companion_libs/130-cloog.sh
+++ b/scripts/build/companion_libs/130-cloog.sh
@@ -101,12 +101,12 @@ do_cloog_backend() {
"${cloog_opts[@]}"
CT_DoLog EXTRA "Building CLooG"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
if [ "${CT_COMPLIBS_CHECK}" = "y" ]; then
if [ "${host}" = "${CT_BUILD}" ]; then
CT_DoLog EXTRA "Checking CLooG"
- CT_DoExecLog ALL make ${JOBSFLAGS} -s check
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} -s check
else
# Cannot run host binaries on build in a canadian cross
CT_DoLog EXTRA "Skipping check for CLooG on the host"
diff --git a/scripts/build/companion_libs/140-mpc.sh b/scripts/build/companion_libs/140-mpc.sh
index 3136ab4..2166ef1 100644
--- a/scripts/build/companion_libs/140-mpc.sh
+++ b/scripts/build/companion_libs/140-mpc.sh
@@ -94,12 +94,12 @@ do_mpc_backend() {
--enable-static
CT_DoLog EXTRA "Building MPC"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
if [ "${CT_COMPLIBS_CHECK}" = "y" ]; then
if [ "${host}" = "${CT_BUILD}" ]; then
CT_DoLog EXTRA "Checking MPC"
- CT_DoExecLog ALL make ${JOBSFLAGS} -s check
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} -s check
else
# Cannot run host binaries on build in a canadian cross
CT_DoLog EXTRA "Skipping check for MPC on the host"
diff --git a/scripts/build/companion_libs/210-expat.sh b/scripts/build/companion_libs/210-expat.sh
index d2ca6a0..68667f6 100644
--- a/scripts/build/companion_libs/210-expat.sh
+++ b/scripts/build/companion_libs/210-expat.sh
@@ -103,7 +103,7 @@ do_expat_backend() {
"${extra_config[@]}"
CT_DoLog EXTRA "Building expat"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
CT_DoLog EXTRA "Installing expat"
CT_DoExecLog ALL make install DESTDIR="${destdir}"
}
diff --git a/scripts/build/companion_libs/220-ncurses.sh b/scripts/build/companion_libs/220-ncurses.sh
index decfa9e..f1fcd1a 100644
--- a/scripts/build/companion_libs/220-ncurses.sh
+++ b/scripts/build/companion_libs/220-ncurses.sh
@@ -174,7 +174,7 @@ do_ncurses_backend() {
# it also builds ncurses anyway, and dedicated targets (install.includes and
# install.progs) do not do well with parallel make (-jX).
CT_DoLog EXTRA "Building ncurses"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
# STRIPPROG is handled by our wrapper around install.
CT_DoLog EXTRA "Installing ncurses"
diff --git a/scripts/build/companion_libs/320-libiconv.sh b/scripts/build/companion_libs/320-libiconv.sh
index ad571a9..9748ba2 100644
--- a/scripts/build/companion_libs/320-libiconv.sh
+++ b/scripts/build/companion_libs/320-libiconv.sh
@@ -100,7 +100,7 @@ do_libiconv_backend() {
"${extra_config[@]}" \
CT_DoLog EXTRA "Building libiconv"
- CT_DoExecLog ALL make CC="${host}-gcc ${cflags}" ${JOBSFLAGS}
+ CT_DoExecLog ALL make CC="${host}-gcc ${cflags}" ${CT_JOBSFLAGS}
CT_DoLog EXTRA "Installing libiconv"
CT_DoExecLog ALL make install CC="${host}-gcc ${cflags}"
diff --git a/scripts/build/companion_libs/330-gettext.sh b/scripts/build/companion_libs/330-gettext.sh
index f3f1497..149d7d7 100644
--- a/scripts/build/companion_libs/330-gettext.sh
+++ b/scripts/build/companion_libs/330-gettext.sh
@@ -131,7 +131,7 @@ do_gettext_backend() {
"${extra_config[@]}"
CT_DoLog EXTRA "Building gettext"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
CT_DoLog EXTRA "Installing gettext"
CT_DoExecLog ALL make install
diff --git a/scripts/build/debug/300-gdb.sh b/scripts/build/debug/300-gdb.sh
index 15e0684..9139331 100644
--- a/scripts/build/debug/300-gdb.sh
+++ b/scripts/build/debug/300-gdb.sh
@@ -67,7 +67,7 @@ do_debug_gdb_build()
if [ "${CT_BUILD_MANUALS}" = "y" ]; then
CT_DoLog EXTRA "Building and installing the cross-GDB manuals"
- CT_DoExecLog ALL make ${JOBSFLAGS} pdf html
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} pdf html
CT_DoExecLog ALL make install-{pdf,html}-gdb
fi
@@ -114,15 +114,15 @@ do_debug_gdb_build()
native_extra_config+=("--disable-gdbserver")
else
native_extra_config+=("--enable-gdbserver")
- if [ "${CT_GDB_NATIVE_BUILD_IPA_LIB}" = "y" ]; then
- gdbserver_extra_config+=("--enable-inprocess-agent")
- else
- gdbserver_extra_config+=("--disable-inprocess-agent")
- fi
if [ "${CT_GDB_NATIVE}" != "y" ]; then
subdir=gdb/gdbserver/
fi
fi
+ if [ "${CT_GDB_NATIVE_BUILD_IPA_LIB}" = "y" ]; then
+ native_extra_config+=("--enable-inprocess-agent")
+ else
+ native_extra_config+=("--disable-inprocess-agent")
+ fi
export ac_cv_func_strncmp_works=yes
@@ -278,7 +278,7 @@ do_gdb_backend()
"${extra_config[@]}" \
CT_DoLog EXTRA "Building ${buildtype} gdb"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
CT_DoLog EXTRA "Installing ${buildtype} gdb"
CT_DoExecLog ALL make install ${destdir:+DESTDIR="${destdir}"}
diff --git a/scripts/build/libc/avr-libc.sh b/scripts/build/libc/avr-libc.sh
index ce63b4a..34eb0f5 100644
--- a/scripts/build/libc/avr-libc.sh
+++ b/scripts/build/libc/avr-libc.sh
@@ -20,7 +20,7 @@ avr_libc_post_cc()
"${CT_LIBC_AVR_LIBC_EXTRA_CONFIG_ARRAY[@]}"
CT_DoLog EXTRA "Building C library"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
CT_DoLog EXTRA "Installing C library"
CT_DoExecLog ALL make install
diff --git a/scripts/build/libc/mingw-w64.sh b/scripts/build/libc/mingw-w64.sh
index a5b89d1..683f8be 100644
--- a/scripts/build/libc/mingw-w64.sh
+++ b/scripts/build/libc/mingw-w64.sh
@@ -196,7 +196,7 @@ mingw_w64_main()
# mingw-w64-crt has a missing dependency occasionally breaking the
# parallel build. See https://github.com/crosstool-ng/crosstool-ng/issues/246
- # Do not pass ${JOBSFLAGS} - build serially.
+ # Do not pass ${CT_JOBSFLAGS} - build serially.
CT_DoLog EXTRA "Building mingw-w64-crt"
CT_DoExecLog ALL make
diff --git a/scripts/build/libc/musl.sh b/scripts/build/libc/musl.sh
index 63d6804..807b3bd 100644
--- a/scripts/build/libc/musl.sh
+++ b/scripts/build/libc/musl.sh
@@ -128,7 +128,7 @@ musl_backend_once() {
"${multi_root}${multilib_dir}/libc.so"
CT_DoLog EXTRA "Building C library"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
CT_DoLog EXTRA "Installing C library"
CT_DoExecLog ALL make DESTDIR="${multi_root}" install
diff --git a/scripts/build/libc/newlib.sh b/scripts/build/libc/newlib.sh
index 69d2b46..95ab791 100644
--- a/scripts/build/libc/newlib.sh
+++ b/scripts/build/libc/newlib.sh
@@ -108,7 +108,7 @@ ENABLE_TARGET_OPTSPACE:target-optspace
"${CT_LIBC_NEWLIB_EXTRA_CONFIG_ARRAY[@]}"
CT_DoLog EXTRA "Building C library"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
CT_DoLog EXTRA "Installing C library"
CT_DoExecLog ALL make install
diff --git a/scripts/build/libc/uClibc.sh b/scripts/build/libc/uClibc.sh
index 2ae6e0c..5c04b32 100644
--- a/scripts/build/libc/uClibc.sh
+++ b/scripts/build/libc/uClibc.sh
@@ -44,7 +44,7 @@ uClibc_backend_once()
local libc_mode
local multi_dir multi_os_dir multi_root multi_flags multi_index multi_count
local multilib_dir startfiles_dir
- local jflag=${CT_LIBC_UCLIBC_PARALLEL:+${JOBSFLAGS}}
+ local jflag=${CT_LIBC_UCLIBC_PARALLEL:+${CT_JOBSFLAGS}}
local -a make_args
local extra_cflags f cfg_cflags cf
local hdr_install_subdir
diff --git a/scripts/build/cc/gcc.sh b/scripts/build/cc/gcc.sh
index ce7fea4..60f259d 100644
--- a/scripts/build/cc/gcc.sh
+++ b/scripts/build/cc/gcc.sh
@@ -618,23 +618,23 @@ do_gcc_core_backend() {
# Next we have to configure gcc, create libgcc.mk then edit it...
# So much easier if we just edit the source tree, but hey...
if [ ! -f "${CT_SRC_DIR}/gcc/gcc/BASE-VER" ]; then
- CT_DoExecLog CFG make ${JOBSFLAGS} configure-libiberty
- CT_DoExecLog ALL make ${JOBSFLAGS} -C libiberty libiberty.a
- CT_DoExecLog CFG make ${JOBSFLAGS} configure-gcc configure-libcpp
- CT_DoExecLog ALL make ${JOBSFLAGS} all-libcpp
+ CT_DoExecLog CFG make ${CT_JOBSFLAGS} configure-libiberty
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} -C libiberty libiberty.a
+ CT_DoExecLog CFG make ${CT_JOBSFLAGS} configure-gcc configure-libcpp
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} all-libcpp
else
- CT_DoExecLog CFG make ${JOBSFLAGS} configure-gcc configure-libcpp configure-build-libiberty
- CT_DoExecLog ALL make ${JOBSFLAGS} all-libcpp all-build-libiberty
+ CT_DoExecLog CFG make ${CT_JOBSFLAGS} configure-gcc configure-libcpp configure-build-libiberty
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} all-libcpp all-build-libiberty
fi
# HACK: gcc-4.2 uses libdecnumber to build libgcc.mk, so build it here.
if [ -d "${CT_SRC_DIR}/gcc/libdecnumber" ]; then
- CT_DoExecLog CFG make ${JOBSFLAGS} configure-libdecnumber
- CT_DoExecLog ALL make ${JOBSFLAGS} -C libdecnumber libdecnumber.a
+ CT_DoExecLog CFG make ${CT_JOBSFLAGS} configure-libdecnumber
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} -C libdecnumber libdecnumber.a
fi
# HACK: gcc-4.8 uses libbacktrace to make libgcc.mvars, so make it here.
if [ -d "${CT_SRC_DIR}/gcc/libbacktrace" ]; then
- CT_DoExecLog CFG make ${JOBSFLAGS} configure-libbacktrace
- CT_DoExecLog ALL make ${JOBSFLAGS} -C libbacktrace
+ CT_DoExecLog CFG make ${CT_JOBSFLAGS} configure-libbacktrace
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} -C libbacktrace
fi
libgcc_rule="libgcc.mvars"
@@ -652,7 +652,7 @@ do_gcc_core_backend() {
repair_cc=""
fi
- CT_DoExecLog ALL make ${JOBSFLAGS} -C gcc ${libgcc_rule} \
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} -C gcc ${libgcc_rule} \
${repair_cc}
sed -r -i -e 's@-lc@@g' gcc/${libgcc_rule}
else # build_libgcc
@@ -681,9 +681,9 @@ do_gcc_core_backend() {
esac
CT_DoLog EXTRA "Building ${log_txt}"
- CT_DoExecLog ALL make ${JOBSFLAGS} ${core_targets_all}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} ${core_targets_all}
- # Do not pass ${JOBSFLAGS} here: recent GCC builds have been failing
+ # Do not pass ${CT_JOBSFLAGS} here: recent GCC builds have been failing
# in parallel 'make install' at random locations: libitm, libcilk,
# always for the files that are installed more than once to the same
# location (such as libitm.info).
@@ -1169,11 +1169,11 @@ do_gcc_backend() {
if [ "${CT_CANADIAN}" = "y" ]; then
CT_DoLog EXTRA "Building libiberty"
- CT_DoExecLog ALL make ${JOBSFLAGS} all-build-libiberty
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} all-build-libiberty
fi
CT_DoLog EXTRA "Building final gcc compiler"
- CT_DoExecLog ALL make ${JOBSFLAGS} all
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} all
# See the note on issues with parallel 'make install' in GCC above.
CT_DoLog EXTRA "Installing final gcc compiler"
diff --git a/scripts/build/libc/glibc.sh b/scripts/build/libc/glibc.sh
index aebc898..221752d 100644
--- a/scripts/build/libc/glibc.sh
+++ b/scripts/build/libc/glibc.sh
@@ -321,7 +321,7 @@ glibc_backend_once()
# use the 'install-headers' makefile target to install the
# headers
- CT_DoExecLog ALL make ${JOBSFLAGS} \
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} \
install_root=${multi_root} \
install-bootstrap-headers=yes \
"${extra_make_args[@]}" \
@@ -371,7 +371,7 @@ glibc_backend_once()
# there are a few object files needed to link shared libraries,
# which we build and install by hand
CT_DoExecLog ALL mkdir -p "${startfiles_dir}"
- CT_DoExecLog ALL make ${JOBSFLAGS} \
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} \
"${extra_make_args[@]}" \
csu/subdir_lib
CT_DoExecLog ALL cp csu/crt1.o csu/crti.o csu/crtn.o \
@@ -392,12 +392,12 @@ glibc_backend_once()
if [ "${libc_mode}" = "final" ]; then
CT_DoLog EXTRA "Building C library"
- CT_DoExecLog ALL make ${JOBSFLAGS} \
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} \
"${extra_make_args[@]}" \
all
CT_DoLog EXTRA "Installing C library"
- CT_DoExecLog ALL make ${JOBSFLAGS} \
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} \
"${extra_make_args[@]}" \
install_root="${multi_root}" \
install
@@ -407,7 +407,7 @@ glibc_backend_once()
# last multilib target. If it's not multilib, it will happen on the
# only target.
CT_DoLog EXTRA "Building and installing the C library manual"
# Omit JOBSFLAGS as GLIBC has problems building the
# manuals in parallel
CT_DoExecLog ALL make pdf html
CT_DoExecLog ALL mkdir -p ${CT_PREFIX_DIR}/share/doc
@@ -546,7 +546,7 @@ glibc_locales()
"${extra_config[@]}"
CT_DoLog EXTRA "Building C library localedef"
- CT_DoExecLog ALL make ${JOBSFLAGS}
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS}
# The target's endianness and uint32_t alignment should be passed as options
# to localedef, but glibc's localedef does not support these options, which
@@ -554,7 +554,7 @@ glibc_locales()
# only if it has the same endianness and uint32_t alignment as the host's.
CT_DoLog EXTRA "Installing C library locales"
- CT_DoExecLog ALL make ${JOBSFLAGS} \
+ CT_DoExecLog ALL make ${CT_JOBSFLAGS} \
install_root="${CT_SYSROOT_DIR}" \
localedata/install-locales
}
@@ -407,7 +407,7 @@ glibc_backend_once()
# only target.
CT_DoLog EXTRA "Building and installing the C library manual"
- # Omit JOBSFLAGS as GLIBC has problems building the
+ # Omit CT_JOBSFLAGS as GLIBC has problems building the
# manuals in parallel
CT_DoExecLog ALL make pdf html